@@ -9,7 +9,7 @@ except ImportError: # pragma: no cover
     from ordereddict import OrderedDict
 
 from journalism.columns import ColumnMapping, NumberType 
-from journalism.exceptions import ColumnDoesNotExistError, UnsupportedOperationError
+from journalism.exceptions import ColumnDoesNotExistError, UnsupportedOperationError, NullComputationError
 from journalism.rows import RowSequence, Row
 
 class Table(object):
@@ -69,7 +69,7 @@ class Table(object):
         if i not in self._cached_columns:
             column_type = self._column_types[i]
 
-            self._cached_columns[i] = column_type.create_column(self, i)
+            self._cached_columns[i] = column_type._create_column(self, i)
 
         return self._cached_columns[i]
 
@@ -223,6 +223,44 @@ class Table(object):
 
         return self.where(f)
 
+    def pearson_correlation(self, column_one, column_two):
+        """
+        Calculates the `Pearson correlation coefficient <http://en.wikipedia.org/wiki/Pearson_product-moment_correlation_coefficient>`_
+        for :code:`column_one` and :code:`column_two`.
+
+        Returns a number between -1 and 1 with 0 implying no correlation. A correlation close to 1 implies a high positive correlation i.e. as x increases so does y. A correlation close to -1 implies a high negative correlation i.e. as x increases, y decreases.
+
+        Note: this implementation is borrowed from the MIT licensed `latimes-calculate <https://github.com/datadesk/latimes-calculate/blob/master/calculate/pearson.py>`_. Thanks, LAT!
+
+        :param column_one: The name of a column.
+        :param column_two: The name of a column.
+        :returns: :class:`decimal.Decimal`.
+        """
+        x = self.columns[column_one]
+        y = self.columns[column_two]
+
+        if x.has_nulls() or y.has_nulls():
+            raise NullComputationError
+
+        n = len(x)
+
+        sum_x = x.sum()
+        sum_y = y.sum()
+
+        square = lambda x: pow(x,2)
+        sum_x_sq = sum(map(square, x))
+        sum_y_sq = sum(map(square, y))
+
+        product_sum = sum((x_val * y_val for x_val, y_val in zip(x, y)))
+
+        pearson_numerator = product_sum - (sum_x * sum_y / n)
+        pearson_denominator = ((sum_x_sq - pow(sum_x, 2) / n) * (sum_y_sq - pow(sum_y, 2) / n)).sqrt()
+
+        if pearson_denominator == 0:
+            return 0
+
+        return pearson_numerator / pearson_denominator
+
     def order_by(self, key, reverse=False):
         """
         Sort this table by the :code:`key`. This can be either a
@@ -441,9 +479,8 @@ class Table(object):
         'group_by_count', 'column_one_operation', ...)`.
 
         :param group_by: The name of a column to group by. 
-        :param operations: A :class:`dict: where the keys are column names
-            and the values are the names of :class:`.Column` methods, such
-            as "sum" or "max_length".
+        :param operations: An iterable of pairs of column names and the 
+            names of :class:`.Column` methods, such as "sum" or "max_length".
         :returns: A new :class:`Table`.
         :raises: :exc:`.ColumnDoesNotExistError`, :exc:`.UnsupportedOperationError`
         """
@@ -563,6 +600,21 @@ class Table(object):
 
         return self.compute(new_column_name, NumberType(), compute_func)
 
+    def z_scores(self,column_name,new_column_name):
+        """ Returns a new column that is the z-score or standard score of 
+        each value returned by the row function.
+        
+        :param column_name: The name of the column for z-scores to be based
+        off of.
+        :param new_column_name: The name of the resulting column.
+        :returns: A new :class:`Table`.
+        """
+        mean = self.columns[column_name].mean()
+        sd = self.columns[column_name].stdev()
+        compute_func = lambda row: (row[column_name]-mean)/sd
+
+        return self.compute(new_column_name, NumberType(), compute_func)
+
 class NullOrder(object):
     """
     Dummy object used for sorting in place of None.
